@@ -13,11 +13,11 @@
  * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-#include "lib.h"
-#include "memlock.h"
-#include "defaults.h"
-#include "config.h"
-#include "toolcontext.h"
+#include "lib/misc/lib.h"
+#include "lib/mm/memlock.h"
+#include "lib/config/defaults.h"
+#include "lib/config/config.h"
+#include "lib/commands/toolcontext.h"
 
 #include <limits.h>
 #include <fcntl.h>
@@ -350,14 +350,14 @@ static int _memlock_maps(struct cmd_context *cmd, lvmlock_t lock, size_t *mstats
 		if (!_maps_buffer || len >= _maps_len) {
 			if (_maps_buffer)
 				_maps_len *= 2;
-			if (!(line = dm_realloc(_maps_buffer, _maps_len))) {
+			if (!(line = realloc(_maps_buffer, _maps_len))) {
 				log_error("Allocation of maps buffer failed.");
 				return 0;
 			}
 			_maps_buffer = line;
 		}
 		if (lseek(_maps_fd, 0, SEEK_SET))
-			log_sys_error("lseek", _procselfmaps);
+			log_sys_debug("lseek", _procselfmaps);
 		for (len = 0 ; len < _maps_len; len += n) {
 			if (!(n = read(_maps_fd, _maps_buffer + len, _maps_len - len)))
 				break; /* EOF */
@@ -551,7 +551,7 @@ static void _lock_mem(struct cmd_context *cmd)
 
 static void _unlock_mem(struct cmd_context *cmd)
 {
-	size_t unlock_mstats;
+	size_t unlock_mstats = 0;
 
 	log_very_verbose("Unlocking memory");
 
@@ -561,8 +561,8 @@ static void _unlock_mem(struct cmd_context *cmd)
 	if (!_use_mlockall) {
 		_restore_mmap();
 		if (close(_maps_fd))
-			log_sys_error("close", _procselfmaps);
-		dm_free(_maps_buffer);
+			log_sys_debug("close", _procselfmaps);
+		free(_maps_buffer);
 		_maps_buffer = NULL;
 		if (_mstats < unlock_mstats) {
 			if ((_mstats + lvm_getpagesize()) < unlock_mstats)
@@ -615,8 +615,7 @@ static void _unlock_mem_if_possible(struct cmd_context *cmd)
 void critical_section_inc(struct cmd_context *cmd, const char *reason)
 {
 	if (!_critical_section &&
-	    ((strcmp(reason, "suspending") == 0) ||
-	     (strcmp(reason, "locking for suspend") == 0))) {
+	    (strcmp(reason, "suspending") == 0)) {
 		/*
 		 * Profiles are loaded on-demand so make sure that before
 		 * entering the critical section all needed profiles are
